#!/bin/bash
#
# package.sh - automated packaging in Guy's developer environment.
#
# You may use a command like
#   dpkg-buildpackage -B -uc -rfakeroot
# or similar instead

if [ -e ../../scripts/package.sh ]; then
   ../../scripts/package.sh guymager-beta
else
   ../../../scripts/package.sh guymager-beta # when called from the branches or tags directories
fi

./compileinfo.sh | grep Version | awk -F\" ' { print "Version "$2 } '

